| scotus.1937.2021 | R Documentation |
This dataset contains voting records from the U.S. Supreme Court between 1937 and 2021. Loading 'data(scotus.1937.2021)' will load the following two independent objects into the environment:
data(scotus.1937.2021)
The dataset consists of the following two objects:
A '48 × 6108' matrix, where each row represents a judge and each column represents a case. Entries are:
'1' ('TRUE'): The judge voted to reverse the lower court decision.
'0' ('FALSE'): The judge voted to uphold the lower court decision.
'NA': The judge did not vote on the case.
A numeric vector of length '6108', indicating the time period associated with each case.
The data were obtained from the Martin-Quinn Scores Database, maintained by Washington University in St. Louis.
data(scotus.1937.2021)
str(mqVotes)
str(mqTime)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.