- votes
A `452 × 952` matrix of roll call votes, where each row represents a legislator and each column represents a vote.
- codes
A list containing vote codes:
- n
Integer, number of legislators (452).
- m
Integer, number of votes (952).
- legis.data
A data frame (`452 × 6`) containing legislator information:
- vote.data
Currently NULL (reserved for additional vote metadata).
- desc
Description: `"116th U.S. House of Representatives"`.
- source
URL for the original data source.