Learn R Programming

pumBayes (version 1.0.2)

scotus.1937.2021: U.S. Supreme Court Voting Data (1937-2021)

Description

This dataset contains voting records from the U.S. Supreme Court between 1937 and 2021. Loading `data(scotus.1937.2021)` will load the following two independent objects into the environment:

Usage

data(scotus.1937.2021)

Arguments

Format

The dataset consists of the following two objects:

mqVotes

A `48 × 6108` matrix, where each row represents a judge and each column represents a case. Entries are:

  • `1` (`TRUE`): The judge voted to reverse the lower court decision.

  • `0` (`FALSE`): The judge voted to uphold the lower court decision.

  • `NA`: The judge did not vote on the case.

mqTime

A numeric vector of length `6108`, indicating the time period associated with each case.

Examples

Run this code
data(scotus.1937.2021)
str(mqVotes)
str(mqTime)

Run the code above in your browser using DataLab